@@ -31,10 +31,8 @@ pub use names::{Name, OptName, QualifiedName};
 pub use scope::Scope;
 pub use temporal::date::FeelDate;
 pub use temporal::dt_duration::FeelDaysAndTimeDuration;
-pub use temporal::subtract;
 pub use temporal::ym_duration::FeelYearsAndMonthsDuration;
-pub use temporal::FeelDateTime;
-pub use temporal::FeelTime;
+pub use temporal::{subtract, FeelDateTime, FeelTime};
 pub use types::{is_built_in_type_name, FeelType};
 
 mod ast;
