@@ -14,7 +14,10 @@
 
 //! `FEEL` days and time durations.
 
-use {self::errors::*, dmntk_common::DmntkError, regex::Regex, std::convert::TryFrom};
+use self::errors::*;
+use dmntk_common::DmntkError;
+use regex::Regex;
+use std::convert::TryFrom;
 
 /// Regular expression pattern for parsing days and time duration.
 const REGEX_DAYS_AND_TIME: &str =
@@ -260,14 +263,10 @@ pub mod errors {
 
 #[cfg(test)]
 mod tests {
-  use {
-    super::super::nanoseconds_to_string,
-    super::FeelDaysAndTimeDuration,
-    std::{
-      cmp::Ordering,
-      convert::{TryFrom, TryInto},
-    },
-  };
+  use super::super::nanoseconds_to_string;
+  use super::FeelDaysAndTimeDuration;
+  use std::cmp::Ordering;
+  use std::convert::{TryFrom, TryInto};
 
   /// Utility function for testing days and time durations equality.
   fn equals(sec: i64, nano: u64, text: &str) {
