@@ -16,16 +16,13 @@
 
 //! Definitions of `FEEL` types.
 
-use {
-  self::errors::*,
-  crate::{
-    context::FeelContext,
-    names::Name,
-    values::{Value, Values, VALUE_NULL},
-  },
-  dmntk_common::{DmntkError, Result, Stringify},
-  std::{collections::BTreeMap, str::FromStr},
-};
+use self::errors::*;
+use crate::context::FeelContext;
+use crate::names::Name;
+use crate::values::{Value, Values, VALUE_NULL};
+use dmntk_common::{DmntkError, Result, Stringify};
+use std::collections::BTreeMap;
+use std::str::FromStr;
 
 pub const FEEL_TYPE_NAME_ANY: &str = "Any";
 const FEEL_TYPE_NAME_BOOLEAN: &str = "boolean";
@@ -426,14 +423,10 @@ mod errors {
 
 #[cfg(test)]
 mod tests {
-  use crate::{
-    names::Name,
-    types::{
-      is_built_in_type_name,
-      FeelType::{self, Any, Number},
-    },
-    values::Value,
-  };
+  use crate::names::Name;
+  use crate::types::is_built_in_type_name;
+  use crate::types::FeelType::{self, Any, Number};
+  use crate::values::Value;
 
   #[test]
   fn test_retrieve_value_with_type_checking() {
